﻿using Syncfusion.UI.Xaml.RichTextBoxAdv;
using System;
using System.Collections.Generic;
using System.IO;
using System.Linq;
using System.Reflection;
using Windows.Foundation;
using Windows.Foundation.Collections;
using Windows.Graphics.Printing;
using Windows.Storage;
using Windows.Storage.Pickers;
using Windows.UI;
using Windows.UI.Popups;
using Windows.UI.ViewManagement;
using Windows.UI.Xaml;
using Windows.UI.Xaml.Controls;
using Windows.UI.Xaml.Controls.Primitives;
using Windows.UI.Xaml.Data;
using Windows.UI.Xaml.Input;
using Windows.UI.Xaml.Media;
using Windows.UI.Xaml.Navigation;
using Windows.UI.Xaml.Printing;

namespace SfRTESample
{
    public partial class MainPage : Page
    {
        /// <summary>
        /// Initializes a new instance of the <see cref="MainPage"/> class.
        /// </summary>
        public MainPage()
        {
            this.InitializeComponent();
        }
        /// <summary>
        /// Invoked when this page is about to be displayed in a Frame.
        /// </summary>
        /// <param name="e">Event data that describes how this page was reached.  The Parameter
        /// property is typically used to configure the page.</param>
        protected override void OnNavigatedTo(NavigationEventArgs e)
        {
        }
        /// <summary>
        /// Invoked immediately after the Page is unloaded and is no longer the current source of a parent Frame.
        /// </summary>
        /// <param name="e">Event data that can be examined by overriding code. The event data is representative of the navigation that has unloaded the current Page.</param>
        protected override void OnNavigatedFrom(NavigationEventArgs e)
        {
        }
        private void LoadRtfButton_Click(object sender, RoutedEventArgs e)
        {
            Assembly asm = typeof(MainPage).GetTypeInfo().Assembly;
            Stream stream = asm.GetManifestResourceStream("SfRTESample.Assets.SampleRTF.rtf");
            richTextBox.Load(stream, FormatType.Rtf);
            ClearFontSize();
        }
        /// <summary>
        /// Clears the size of the font.
        /// </summary>
        private void ClearFontSize()
        {
            // Clears the font size property defined for document
            // We can also set the font size instead of clearing
            richTextBox.Document.CharacterFormat.ClearValue(CharacterFormat.FontSizeProperty);
            for (int i = 0; i < richTextBox.Document.Sections.Count; i++)
                ClearFontSize(richTextBox.Document.Sections[i]);
        }
        /// <summary>
        /// Clears the size of the font.
        /// </summary>
        /// <param name="section">The section.</param>
        private void ClearFontSize(SectionAdv section)
        {
            for (int i = 0; i < section.Blocks.Count; i++)
                ClearFontSize(section.Blocks[i]);
        }
        /// <summary>
        /// Clears the size of the font.
        /// </summary>
        /// <param name="block">The block.</param>
        private void ClearFontSize(BlockAdv block)
        {
            if (block is ParagraphAdv)
                ClearFontSize(block as ParagraphAdv);
            else
                ClearFontSize(block as TableAdv);
        }
        /// <summary>
        /// Clears the size of the font.
        /// </summary>
        /// <param name="table">The table.</param>
        private void ClearFontSize(TableAdv table)
        {
            for (int i = 0; i < table.Rows.Count; i++)
                ClearFontSize(table.Rows[i]);
        }
        /// <summary>
        /// Clears the size of the font.
        /// </summary>
        /// <param name="tableRow">The table row.</param>
        private void ClearFontSize(TableRowAdv tableRow)
        {
            for (int i = 0; i < tableRow.Cells.Count; i++)
                ClearFontSize(tableRow.Cells[i]);
        }
        /// <summary>
        /// Clears the size of the font.
        /// </summary>
        /// <param name="tableCell">The table cell.</param>
        private void ClearFontSize(TableCellAdv tableCell)
        {
            for (int i = 0; i < tableCell.Blocks.Count; i++)
                ClearFontSize(tableCell.Blocks[i]);
        }
        /// <summary>
        /// Clears the size of the font.
        /// </summary>
        /// <param name="paragraph">The paragraph.</param>
        private void ClearFontSize(ParagraphAdv paragraph)
        {
            // Clears the font size property defined for Paragraph
            // We can also set the font size instead of clearing
            paragraph.CharacterFormat.ClearValue(CharacterFormat.FontSizeProperty);
            // Clears the font size property defined inline
            // We can also set the font size instead of clearing
            for (int i = 0; i < paragraph.Inlines.Count; i++)
                paragraph.Inlines[i].CharacterFormat.ClearValue(CharacterFormat.FontSizeProperty);
        }
    }
}
